@@ -22,23 +22,29 @@ use Twitter::Text::Regexp;
 use Twitter::Text::Regexp::Emoji;
 use Unicode::Normalize qw(NFC);
 
-our $VERSION = "0.01";
-our @EXPORT = qw(
-    extract_cashtags
-    extract_cashtags_with_indices
-    extract_hashtags
-    extract_hashtags_with_indices
-    extract_mentioned_screen_names
-    extract_mentioned_screen_names_with_indices
-    extract_mentions_or_lists_with_indices
-    extract_urls
-    extract_urls_with_indices
-    is_valid_hashtag
-    is_valid_list
-    is_valid_tweet
-    is_valid_url
-    is_valid_username
-    parse_tweet
+our $VERSION = "0.02";
+our @EXPORT = (
+    # Extraction
+    qw(
+        extract_cashtags
+        extract_cashtags_with_indices
+        extract_hashtags
+        extract_hashtags_with_indices
+        extract_mentioned_screen_names
+        extract_mentioned_screen_names_with_indices
+        extract_mentions_or_lists_with_indices
+        extract_urls
+        extract_urls_with_indices
+    ),
+    # Validation
+    qw(
+        is_valid_hashtag
+        is_valid_list
+        is_valid_tweet
+        is_valid_url
+        is_valid_username
+        parse_tweet
+    ),
 );
 
 sub extract_emoji_with_indices {
@@ -108,11 +114,11 @@ sub extract_hashtags_with_indices {
 
     my $tags = [];
 
-    while ($text =~ /($Twitter::Text::Regexp::valid_hashtag)/g) {
+    while ($text =~ /($Twitter::Text::Regexp::valid_hashtag)/gp) {
         my ($before, $hash, $hash_text) = ($2, $3, $4);
         my $start_position = $-[3];
         my $end_position = $+[4];
-        my $after = $';
+        my $after = ${^POSTMATCH};
         unless ($after =~ $Twitter::Text::Regexp::end_hashtag_match) {
             push @$tags, {
                 hashtag => $hash_text,
@@ -163,11 +169,11 @@ sub extract_mentions_or_lists_with_indices {
     return [] unless $text =~ /[@＠]/;
 
     my $possible_entries = [];
-    while ($text =~ /($Twitter::Text::Regexp::valid_mention_or_list)/g) {
+    while ($text =~ /($Twitter::Text::Regexp::valid_mention_or_list)/gp) {
         my ($before, $at, $screen_name, $list_slug) = ($2, $3, $4, $5);
         my $start_position = $-[4] - 1;
         my $end_position = $+[defined $list_slug ? 5 : 4];
-        my $after = $';
+        my $after = ${^POSTMATCH};
         unless ($after =~ $Twitter::Text::Regexp::end_mention_match) {
             push @$possible_entries, {
                 screen_name => $screen_name,
@@ -307,8 +313,8 @@ sub is_valid_url {
 
 sub valid_match {
     my ($string, $regex, $optional) = @_;
-    return (defined $string && ($string =~ $regex) && $& eq $string) unless $optional;
-    return !(defined $string && (!($string =~ $regex) || $& ne $string));
+    return (defined $string && ($string =~ /($regex)/) && $1 eq $string) unless $optional;
+    return !(defined $string && (!($string =~ /($regex)/) || $1 ne $string));
 }
 
 sub is_valid_username {
@@ -464,10 +470,12 @@ Twitter::Text is a Perl implementation of the twitter-text parsing library.
 
 This library does not implement auto-linking and hit highlighting.
 
-Please refer L<Implementation progress|https://github.com/utgwkk/Twitter-Text/issues/5> for latest status.
+Please refer L<Implementation status|https://github.com/utgwkk/Twitter-Text/issues/5> for latest status.
 
 =head1 FUNCTIONS
 
+All functions below are exported by default.
+
 =head2 Extraction
 
 =head3 extract_hashtags
@@ -508,18 +516,45 @@ The C<parse_tweet> function takes a C<$text> string and optional C<\%options> pa
 
 =over 4
 
-=item C<weighted_length>: the overall length of the tweet with code points weighted per the ranges defined in the configuration file.
+=item C<weighted_length>
 
-=item C<permillage>: indicates the proportion (per thousand) of the weighted length in comparison to the max weighted length. A value > 1000 indicates input text that is longer than the allowable maximum.
+The overall length of the tweet with code points weighted per the ranges defined in the configuration file.
 
-=item C<valid>: indicates if input text length corresponds to a valid result.
+=item C<permillage>
 
-=item C<display_range_start>, C<display_range_end>: An array reference of two unicode code point indices identifying the inclusive start and exclusive end of the displayable content of the Tweet.
+Indicates the proportion (per thousand) of the weighted length in comparison to the max weighted length. A value > 1000 indicates input text that is longer than the allowable maximum.
 
-=item C<vaildRangeStart>, C<valid_range_end>: An array reference of two unicode code point indices identifying the inclusive start and exclusive end of the valid content of the Tweet.
+=item C<valid>
+
+Indicates if input text length corresponds to a valid result.
+
+=item C<display_range_start>, C<display_range_end>
+
+An array of two unicode code point indices identifying the inclusive start and exclusive end of the displayable content of the Tweet.
+
+=item C<valid_range_start>, C<valid_range_end>
+
+An array of two unicode code point indices identifying the inclusive start and exclusive end of the valid content of the Tweet.
 
 =back
 
+=head4 EXAMPLES
+
+    use Data::Dumper;
+    use Twitter::Text;
+
+    $result = parse_tweet('Hello world こんにちは世界');
+    print Dumper($result);
+    # $VAR1 = {
+    #       'weighted_length' => 33
+    #       'permillage' => 117,
+    #       'valid' => 1,
+    #       'display_range_start' => 0,
+    #       'display_range_end' => 32,
+    #       'valid_range_start' => 0,
+    #       'valid_range_end' => 32,
+    #     };
+
 =head3 is_valid_hashtag
 
     my $valid = is_valid_hashtag($hashtag);
